Page 52 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 52

Home

    Despite the overwhelming evidence to the contrary,
    historians have attempted to whitewash the role of Marat
    and his followers by writing that "the people of Paris,
    overcome by panic, marched to the prisons and
    massacred the prisoners."'°

    The truth is that the assassins were a group of less
    than three-hundred men, most of whom were Marseillais

    and

    promise of wine and booty in addition to their salary.
    There is evidence that a drug was put in the drink

    distributed to the assassins. The drug inspired terrible

    fury and left them without reason. Some witnesses

    recorded that, because of the drug, most of these
    assassins died in misery, with an insatiable thirst, and
    unable to sleep for weeks.

    Although many priests perished in the massacres of
    September (1792), the real work of destroying
    Christianity in France (Catholic and Protestant alike) did
    not begin until the 6th of November 1793. The signal for
    the desecration of the churches and imprisonment of the
    priests throughout France began with the bishop of Paris
    (Gobel) being forced to publicly denounce the Catholic
    religion and declaring that there should be no other
    worship than that of "liberty and holy equality."

    Notre Dame was stripped of its crucifixes and images
    of the saints and, on November 10, the Feast of Reason

    the

    real

    work

    of

    47

    The French Revolution

    Marat blamed the assassinations on the people.

    and released convicts. A few were middle class

    tradesmen. The most willing to do the hideous work

    were men of education. The rest were persuaded by the